SUPPORTED_DEVICES = ['HF367x/01', 'HF367x/60']
LIGHT_CURVES = {'HF367x/01': {'sunny day': 0, 'island red': 1,'nordic white': 2}, 'HF367x/60': {'sunny day': 0, 'island red': 1,'nordic white': 2, 'caribbean red': 3}}
SOUND_SOURCE_ALARM = {'wake-up': 'wus', 'radio': 'fmr', 'off': 'off'}
SOUND_CHANNEL_ALARM = {'forest birds': '1', 
                    'summer birds': '2',
                    'buddha wakeup': '3',
                    'morning alps': '4',
                    'yoga harmony': '5',
                    'nepal bowls': '6',
                    'summer lake': '7',
                    'ocean waves': '8',
                    }
SOUND_SOURCE_DUSK = {'radio': 'fmr', 'off': 'off','dusk': 'dus'}
SOUND_CHANNEL_DUSK = {'soft rain': '1', 'ocean waves': '2', 'under water': '3', 'summer lake': '4'}
SOUND_DUSK = {'soft rain': '1', 'ocean waves': '2', 'under water': '3', 'summer lake': '4', 'fm 1': 1, 'fm 2': 2, 'fm 3': 3, 'fm 4': 4, 'fm 5': 5, 'off': 'off'}

SOURCES = {'AUX': 'aux', 'FM 1': 1,'FM 2': 2,'FM 3': 3,'FM 4': 4,'FM 5': 5, 'Other': 'other'}

DAYS = {0: 'tomorrow', 2: 'mon', 4: 'tue', 8: 'wed', 16: 'thu', 32: 'fri', 64: 'sat', 128: 'sun'}
DAYS_TYPE = {0: 'tomorrow', 62: 'workdays', 192: 'weekend', 254: 'daily'}

STATUS = {1: 'off', 777: 'sunset', 2321: 'snooze', 2309: 'wake-up', 2817: 'on'}
